==> zio-aws-elasticbeanstalk_2.12-5.17.104.12-sources.jar: zio/aws/elasticbeanstalk/model/UpdateApplicationVersionResponse.scala <==
package zio.aws.elasticbeanstalk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateApplicationVersionResponse(
    applicationVersion: Option[
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse = {
    import UpdateApplicationVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
      .builder()
      .optionallyWith(applicationVersion.map(value => value.buildAwsValue()))(
        _.applicationVersion
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse.ReadOnly =
    zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse
      .wrap(buildAwsValue())
}
object UpdateApplicationVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse =
      zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse(
        applicationVersion.map(value => value.asEditable)
      )
    def applicationVersion: Option[
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.ReadOnly
    ]
    def getApplicationVersion: ZIO[
      Any,
      AwsError,
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.ReadOnly
    ] = AwsError.unwrapOptionField("applicationVersion", applicationVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
  ) extends zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse.ReadOnly {
    override val applicationVersion: Option[
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.ReadOnly
    ] = scala
      .Option(impl.applicationVersion())
      .map(value =>
        zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
  ): zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticbeanstalk_2.12-6.20.69.1-sources.jar: zio/aws/elasticbeanstalk/model/UpdateApplicationVersionResponse.scala <==
package zio.aws.elasticbeanstalk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateApplicationVersionResponse(
    applicationVersion: Optional[
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse = {
    import UpdateApplicationVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
      .builder()
      .optionallyWith(applicationVersion.map(value => value.buildAwsValue()))(
        _.applicationVersion
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse.ReadOnly =
    zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse
      .wrap(buildAwsValue())
}
object UpdateApplicationVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse =
      zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse(
        applicationVersion.map(value => value.asEditable)
      )
    def applicationVersion: Optional[
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.ReadOnly
    ]
    def getApplicationVersion: ZIO[
      Any,
      AwsError,
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.ReadOnly
    ] = AwsError.unwrapOptionField("applicationVersion", applicationVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
  ) extends zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse.ReadOnly {
    override val applicationVersion: Optional[
      zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.applicationVersion())
      .map(value =>
        zio.aws.elasticbeanstalk.model.ApplicationVersionDescription.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.UpdateApplicationVersionResponse
  ): zio.aws.elasticbeanstalk.model.UpdateApplicationVersionResponse.ReadOnly =
    new Wrapper(impl)
}
